Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PreMiddlewareProvider ¶
PreMiddlewareProvider is a special middleware provider which will be executed before other middlewares on the same "routing" level (AfterRouting/Group/Methods/Any, but not BeforeRouting). A route can do something (e.g.: set middleware options) at the place where it is declared, and the code will be executed before other middlewares which are added before the declaration. Use cases: mark a route with some meta info, set some options for middlewares, etc.
type ResponseStatusProvider ¶
type ResponseStatusProvider interface {
WrittenStatus() int
}
ResponseStatusProvider is an interface to get the written status in the response Many packages need this interface, so put it in the separate package to avoid import cycle